/****************************************************************************
** Meta object code from reading C++ file 'appsettings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ghostwriter-26.07.80/src/settings/appsettings.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'appsettings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11ghostwriter11AppSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto ghostwriter::AppSettings::qt_create_metaobjectdata<qt_meta_tag_ZN11ghostwriter11AppSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ghostwriter::AppSettings",
        "backupLocationChanged",
        "",
        "backupLocation",
        "autoSaveChanged",
        "enabled",
        "backupFileChanged",
        "previewTextFontChanged",
        "QFont",
        "font",
        "previewCodeFontChanged",
        "tabWidthChanged",
        "width",
        "insertSpacesForTabsChanged",
        "useUnderlineForEmphasisChanged",
        "largeHeadingSizesChanged",
        "autoMatchChanged",
        "autoMatchCharChanged",
        "openingChar",
        "bulletPointCyclingChanged",
        "focusModeChanged",
        "FocusMode",
        "focusMode",
        "hideMenuBarInFullScreenChanged",
        "fileHistoryChanged",
        "folderViewShowAllFilesChanged",
        "displayTimeInFullScreenChanged",
        "spellCheckSettingsChanged",
        "editorWidthChanged",
        "EditorWidth",
        "editorWidth",
        "interfaceStyleChanged",
        "InterfaceStyle",
        "style",
        "italicizeBlockquotesChanged",
        "currentHtmlExporterChanged",
        "Exporter*",
        "exporter",
        "showUnbreakableSpaceEnabledChanged",
        "setBackupLocation",
        "setAutoSaveEnabled",
        "setBackupFileEnabled",
        "setTabWidth",
        "setInsertSpacesForTabsEnabled",
        "setUseUnderlineForEmphasis",
        "setLargeHeadingSizesEnabled",
        "setAutoMatchEnabled",
        "setAutoMatchCharEnabled",
        "openingCharacter",
        "setBulletPointCyclingEnabled",
        "setHideMenuBarInFullScreenEnabled",
        "setFavoriteStatistic",
        "value",
        "setRestoreSessionEnabled",
        "setFileHistoryEnabled",
        "setFolderViewShowAllFilesEnabled",
        "setDisplayTimeInFullScreenEnabled",
        "setCurrentHtmlExporter",
        "setShowUnbreakableSpaceEnabled"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'backupLocationChanged'
        QtMocHelpers::SignalData<void(QString)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'autoSaveChanged'
        QtMocHelpers::SignalData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'backupFileChanged'
        QtMocHelpers::SignalData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'previewTextFontChanged'
        QtMocHelpers::SignalData<void(const QFont &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'previewCodeFontChanged'
        QtMocHelpers::SignalData<void(const QFont &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'tabWidthChanged'
        QtMocHelpers::SignalData<void(int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Signal 'insertSpacesForTabsChanged'
        QtMocHelpers::SignalData<void(bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'useUnderlineForEmphasisChanged'
        QtMocHelpers::SignalData<void(bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'largeHeadingSizesChanged'
        QtMocHelpers::SignalData<void(bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'autoMatchChanged'
        QtMocHelpers::SignalData<void(bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'autoMatchCharChanged'
        QtMocHelpers::SignalData<void(const QChar, bool)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QChar, 18 }, { QMetaType::Bool, 5 },
        }}),
        // Signal 'bulletPointCyclingChanged'
        QtMocHelpers::SignalData<void(bool)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'focusModeChanged'
        QtMocHelpers::SignalData<void(FocusMode)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Signal 'hideMenuBarInFullScreenChanged'
        QtMocHelpers::SignalData<void(bool)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'fileHistoryChanged'
        QtMocHelpers::SignalData<void(bool)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'folderViewShowAllFilesChanged'
        QtMocHelpers::SignalData<void(bool)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'displayTimeInFullScreenChanged'
        QtMocHelpers::SignalData<void(bool)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'spellCheckSettingsChanged'
        QtMocHelpers::SignalData<void() const>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'editorWidthChanged'
        QtMocHelpers::SignalData<void(EditorWidth)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
        // Signal 'interfaceStyleChanged'
        QtMocHelpers::SignalData<void(InterfaceStyle)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 33 },
        }}),
        // Signal 'italicizeBlockquotesChanged'
        QtMocHelpers::SignalData<void(bool)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'currentHtmlExporterChanged'
        QtMocHelpers::SignalData<void(Exporter *)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 37 },
        }}),
        // Signal 'showUnbreakableSpaceEnabledChanged'
        QtMocHelpers::SignalData<void(bool)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'setBackupLocation'
        QtMocHelpers::SlotData<void(QString)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'setAutoSaveEnabled'
        QtMocHelpers::SlotData<void(bool)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'setBackupFileEnabled'
        QtMocHelpers::SlotData<void(bool)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'setTabWidth'
        QtMocHelpers::SlotData<void(int)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Slot 'setInsertSpacesForTabsEnabled'
        QtMocHelpers::SlotData<void(bool)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'setUseUnderlineForEmphasis'
        QtMocHelpers::SlotData<void(bool)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'setLargeHeadingSizesEnabled'
        QtMocHelpers::SlotData<void(bool)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'setAutoMatchEnabled'
        QtMocHelpers::SlotData<void(bool)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'setAutoMatchCharEnabled'
        QtMocHelpers::SlotData<void(const QChar, bool)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QChar, 48 }, { QMetaType::Bool, 5 },
        }}),
        // Slot 'setBulletPointCyclingEnabled'
        QtMocHelpers::SlotData<void(bool)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'setHideMenuBarInFullScreenEnabled'
        QtMocHelpers::SlotData<void(bool)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'setFavoriteStatistic'
        QtMocHelpers::SlotData<void(int)>(51, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 52 },
        }}),
        // Slot 'setRestoreSessionEnabled'
        QtMocHelpers::SlotData<void(bool)>(53, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'setFileHistoryEnabled'
        QtMocHelpers::SlotData<void(bool)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'setFolderViewShowAllFilesEnabled'
        QtMocHelpers::SlotData<void(bool)>(55, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'setDisplayTimeInFullScreenEnabled'
        QtMocHelpers::SlotData<void(bool)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'setCurrentHtmlExporter'
        QtMocHelpers::SlotData<void(Exporter *)>(57, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 37 },
        }}),
        // Slot 'setShowUnbreakableSpaceEnabled'
        QtMocHelpers::SlotData<void(bool)>(58, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AppSettings, qt_meta_tag_ZN11ghostwriter11AppSettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ghostwriter::AppSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ghostwriter11AppSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ghostwriter11AppSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11ghostwriter11AppSettingsE_t>.metaTypes,
    nullptr
} };

void ghostwriter::AppSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AppSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->backupLocationChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->autoSaveChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->backupFileChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->previewTextFontChanged((*reinterpret_cast<std::add_pointer_t<QFont>>(_a[1]))); break;
        case 4: _t->previewCodeFontChanged((*reinterpret_cast<std::add_pointer_t<QFont>>(_a[1]))); break;
        case 5: _t->tabWidthChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->insertSpacesForTabsChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->useUnderlineForEmphasisChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->largeHeadingSizesChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->autoMatchChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->autoMatchCharChanged((*reinterpret_cast<std::add_pointer_t<QChar>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 11: _t->bulletPointCyclingChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->focusModeChanged((*reinterpret_cast<std::add_pointer_t<FocusMode>>(_a[1]))); break;
        case 13: _t->hideMenuBarInFullScreenChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->fileHistoryChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->folderViewShowAllFilesChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->displayTimeInFullScreenChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->spellCheckSettingsChanged(); break;
        case 18: _t->editorWidthChanged((*reinterpret_cast<std::add_pointer_t<EditorWidth>>(_a[1]))); break;
        case 19: _t->interfaceStyleChanged((*reinterpret_cast<std::add_pointer_t<InterfaceStyle>>(_a[1]))); break;
        case 20: _t->italicizeBlockquotesChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 21: _t->currentHtmlExporterChanged((*reinterpret_cast<std::add_pointer_t<Exporter*>>(_a[1]))); break;
        case 22: _t->showUnbreakableSpaceEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 23: _t->setBackupLocation((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 24: _t->setAutoSaveEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 25: _t->setBackupFileEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 26: _t->setTabWidth((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 27: _t->setInsertSpacesForTabsEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 28: _t->setUseUnderlineForEmphasis((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 29: _t->setLargeHeadingSizesEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 30: _t->setAutoMatchEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 31: _t->setAutoMatchCharEnabled((*reinterpret_cast<std::add_pointer_t<QChar>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 32: _t->setBulletPointCyclingEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 33: _t->setHideMenuBarInFullScreenEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 34: _t->setFavoriteStatistic((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 35: _t->setRestoreSessionEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 36: _t->setFileHistoryEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 37: _t->setFolderViewShowAllFilesEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 38: _t->setDisplayTimeInFullScreenEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 39: _t->setCurrentHtmlExporter((*reinterpret_cast<std::add_pointer_t<Exporter*>>(_a[1]))); break;
        case 40: _t->setShowUnbreakableSpaceEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AppSettings::*)(QString )>(_a, &AppSettings::backupLocationChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppSettings::*)(bool )>(_a, &AppSettings::autoSaveChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppSettings::*)(bool )>(_a, &AppSettings::backupFileChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppSettings::*)(const QFont & )>(_a, &AppSettings::previewTextFontChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppSettings::*)(const QFont & )>(_a, &AppSettings::previewCodeFontChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppSettings::*)(int )>(_a, &AppSettings::tabWidthChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppSettings::*)(bool )>(_a, &AppSettings::insertSpacesForTabsChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppSettings::*)(bool )>(_a, &AppSettings::useUnderlineForEmphasisChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppSettings::*)(bool )>(_a, &AppSettings::largeHeadingSizesChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppSettings::*)(bool )>(_a, &AppSettings::autoMatchChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppSettings::*)(const QChar , bool )>(_a, &AppSettings::autoMatchCharChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppSettings::*)(bool )>(_a, &AppSettings::bulletPointCyclingChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppSettings::*)(FocusMode )>(_a, &AppSettings::focusModeChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppSettings::*)(bool )>(_a, &AppSettings::hideMenuBarInFullScreenChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppSettings::*)(bool )>(_a, &AppSettings::fileHistoryChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppSettings::*)(bool )>(_a, &AppSettings::folderViewShowAllFilesChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppSettings::*)(bool )>(_a, &AppSettings::displayTimeInFullScreenChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppSettings::*)() const>(_a, &AppSettings::spellCheckSettingsChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppSettings::*)(EditorWidth )>(_a, &AppSettings::editorWidthChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppSettings::*)(InterfaceStyle )>(_a, &AppSettings::interfaceStyleChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppSettings::*)(bool )>(_a, &AppSettings::italicizeBlockquotesChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppSettings::*)(Exporter * )>(_a, &AppSettings::currentHtmlExporterChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppSettings::*)(bool )>(_a, &AppSettings::showUnbreakableSpaceEnabledChanged, 22))
            return;
    }
}

const QMetaObject *ghostwriter::AppSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ghostwriter::AppSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ghostwriter11AppSettingsE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ghostwriter::AppSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 41)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 41;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 41)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 41;
    }
    return _id;
}

// SIGNAL 0
void ghostwriter::AppSettings::backupLocationChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ghostwriter::AppSettings::autoSaveChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ghostwriter::AppSettings::backupFileChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ghostwriter::AppSettings::previewTextFontChanged(const QFont & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void ghostwriter::AppSettings::previewCodeFontChanged(const QFont & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void ghostwriter::AppSettings::tabWidthChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void ghostwriter::AppSettings::insertSpacesForTabsChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void ghostwriter::AppSettings::useUnderlineForEmphasisChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void ghostwriter::AppSettings::largeHeadingSizesChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void ghostwriter::AppSettings::autoMatchChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void ghostwriter::AppSettings::autoMatchCharChanged(const QChar _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2);
}

// SIGNAL 11
void ghostwriter::AppSettings::bulletPointCyclingChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void ghostwriter::AppSettings::focusModeChanged(FocusMode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void ghostwriter::AppSettings::hideMenuBarInFullScreenChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void ghostwriter::AppSettings::fileHistoryChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void ghostwriter::AppSettings::folderViewShowAllFilesChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void ghostwriter::AppSettings::displayTimeInFullScreenChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void ghostwriter::AppSettings::spellCheckSettingsChanged()const
{
    QMetaObject::activate(const_cast< ghostwriter::AppSettings *>(this), &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void ghostwriter::AppSettings::editorWidthChanged(EditorWidth _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void ghostwriter::AppSettings::interfaceStyleChanged(InterfaceStyle _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void ghostwriter::AppSettings::italicizeBlockquotesChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void ghostwriter::AppSettings::currentHtmlExporterChanged(Exporter * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1);
}

// SIGNAL 22
void ghostwriter::AppSettings::showUnbreakableSpaceEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1);
}
QT_WARNING_POP
