/****************************************************************************
** Meta object code from reading C++ file 'sessionstatistics.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ghostwriter-26.07.80/src/statistics/sessionstatistics.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'sessionstatistics.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11ghostwriter17SessionStatisticsE_t {};
} // unnamed namespace

template <> constexpr inline auto ghostwriter::SessionStatistics::qt_create_metaobjectdata<qt_meta_tag_ZN11ghostwriter17SessionStatisticsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ghostwriter::SessionStatistics",
        "wordCountChanged",
        "",
        "value",
        "pageCountChanged",
        "wordsPerMinuteChanged",
        "writingTimeChanged",
        "idleTimePercentageChanged",
        "percentage",
        "startNewSession",
        "lastWordCount",
        "onDocumentWordCountChanged",
        "newWordCount",
        "onTypingPaused",
        "onTypingResumed",
        "onSessionTimerExpired"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'wordCountChanged'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'pageCountChanged'
        QtMocHelpers::SignalData<void(int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'wordsPerMinuteChanged'
        QtMocHelpers::SignalData<void(int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'writingTimeChanged'
        QtMocHelpers::SignalData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'idleTimePercentageChanged'
        QtMocHelpers::SignalData<void(int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
        // Slot 'startNewSession'
        QtMocHelpers::SlotData<void(int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Slot 'startNewSession'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'onDocumentWordCountChanged'
        QtMocHelpers::SlotData<void(int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Slot 'onTypingPaused'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onTypingResumed'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onSessionTimerExpired'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SessionStatistics, qt_meta_tag_ZN11ghostwriter17SessionStatisticsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ghostwriter::SessionStatistics::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ghostwriter17SessionStatisticsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ghostwriter17SessionStatisticsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11ghostwriter17SessionStatisticsE_t>.metaTypes,
    nullptr
} };

void ghostwriter::SessionStatistics::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SessionStatistics *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->wordCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->pageCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->wordsPerMinuteChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->writingTimeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->idleTimePercentageChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->startNewSession((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->startNewSession(); break;
        case 7: _t->onDocumentWordCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->onTypingPaused(); break;
        case 9: _t->onTypingResumed(); break;
        case 10: _t->onSessionTimerExpired(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SessionStatistics::*)(int )>(_a, &SessionStatistics::wordCountChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionStatistics::*)(int )>(_a, &SessionStatistics::pageCountChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionStatistics::*)(int )>(_a, &SessionStatistics::wordsPerMinuteChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionStatistics::*)(int )>(_a, &SessionStatistics::writingTimeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionStatistics::*)(int )>(_a, &SessionStatistics::idleTimePercentageChanged, 4))
            return;
    }
}

const QMetaObject *ghostwriter::SessionStatistics::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ghostwriter::SessionStatistics::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ghostwriter17SessionStatisticsE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ghostwriter::SessionStatistics::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void ghostwriter::SessionStatistics::wordCountChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ghostwriter::SessionStatistics::pageCountChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ghostwriter::SessionStatistics::wordsPerMinuteChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ghostwriter::SessionStatistics::writingTimeChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void ghostwriter::SessionStatistics::idleTimePercentageChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
