/****************************************************************************
** Meta object code from reading C++ file 'documentmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ghostwriter-26.07.80/src/documentmanager.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'documentmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11ghostwriter15DocumentManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto ghostwriter::DocumentManager::qt_create_metaobjectdata<qt_meta_tag_ZN11ghostwriter15DocumentManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ghostwriter::DocumentManager",
        "documentDisplayNameChanged",
        "",
        "displayName",
        "documentModifiedChanged",
        "modified",
        "operationStarted",
        "description",
        "operationUpdate",
        "operationFinished",
        "documentLoaded",
        "documentClosed",
        "sessionHistoryChanged",
        "setAutoSaveEnabled",
        "enabled",
        "setFileBackupEnabled",
        "setDraftLocation",
        "directory",
        "setBackupLocation",
        "open",
        "openFileAt",
        "Bookmark",
        "location",
        "omitFromHistory",
        "createUntitled",
        "reload",
        "rename",
        "saveFile",
        "save",
        "saveAs",
        "close",
        "exportFile"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'documentDisplayNameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'documentModifiedChanged'
        QtMocHelpers::SignalData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'operationStarted'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'operationUpdate'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'operationUpdate'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Signal 'operationFinished'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'documentLoaded'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'documentClosed'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sessionHistoryChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setAutoSaveEnabled'
        QtMocHelpers::SlotData<void(bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Slot 'setFileBackupEnabled'
        QtMocHelpers::SlotData<void(bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Slot 'setDraftLocation'
        QtMocHelpers::SlotData<void(const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'setBackupLocation'
        QtMocHelpers::SlotData<void(const QString &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'open'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'openFileAt'
        QtMocHelpers::SlotData<void(const Bookmark &, bool)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 }, { QMetaType::Bool, 23 },
        }}),
        // Slot 'openFileAt'
        QtMocHelpers::SlotData<void(const Bookmark &)>(20, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Slot 'createUntitled'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reload'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'rename'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'saveFile'
        QtMocHelpers::SlotData<bool()>(27, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'save'
        QtMocHelpers::SlotData<bool()>(28, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'saveAs'
        QtMocHelpers::SlotData<bool()>(29, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'close'
        QtMocHelpers::SlotData<bool()>(30, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'exportFile'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DocumentManager, qt_meta_tag_ZN11ghostwriter15DocumentManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ghostwriter::DocumentManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ghostwriter15DocumentManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ghostwriter15DocumentManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11ghostwriter15DocumentManagerE_t>.metaTypes,
    nullptr
} };

void ghostwriter::DocumentManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DocumentManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->documentDisplayNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->documentModifiedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->operationStarted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->operationUpdate((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->operationUpdate(); break;
        case 5: _t->operationFinished(); break;
        case 6: _t->documentLoaded(); break;
        case 7: _t->documentClosed(); break;
        case 8: _t->sessionHistoryChanged(); break;
        case 9: _t->setAutoSaveEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->setFileBackupEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->setDraftLocation((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->setBackupLocation((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->open(); break;
        case 14: _t->openFileAt((*reinterpret_cast<std::add_pointer_t<Bookmark>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 15: _t->openFileAt((*reinterpret_cast<std::add_pointer_t<Bookmark>>(_a[1]))); break;
        case 16: _t->createUntitled(); break;
        case 17: _t->reload(); break;
        case 18: _t->rename(); break;
        case 19: { bool _r = _t->saveFile();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 20: { bool _r = _t->save();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 21: { bool _r = _t->saveAs();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 22: { bool _r = _t->close();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 23: _t->exportFile(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DocumentManager::*)(const QString & )>(_a, &DocumentManager::documentDisplayNameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentManager::*)(bool )>(_a, &DocumentManager::documentModifiedChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentManager::*)(const QString & )>(_a, &DocumentManager::operationStarted, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentManager::*)(const QString & )>(_a, &DocumentManager::operationUpdate, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentManager::*)()>(_a, &DocumentManager::operationFinished, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentManager::*)()>(_a, &DocumentManager::documentLoaded, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentManager::*)()>(_a, &DocumentManager::documentClosed, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentManager::*)()>(_a, &DocumentManager::sessionHistoryChanged, 8))
            return;
    }
}

const QMetaObject *ghostwriter::DocumentManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ghostwriter::DocumentManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ghostwriter15DocumentManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ghostwriter::DocumentManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 24;
    }
    return _id;
}

// SIGNAL 0
void ghostwriter::DocumentManager::documentDisplayNameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ghostwriter::DocumentManager::documentModifiedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ghostwriter::DocumentManager::operationStarted(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ghostwriter::DocumentManager::operationUpdate(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 5
void ghostwriter::DocumentManager::operationFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void ghostwriter::DocumentManager::documentLoaded()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void ghostwriter::DocumentManager::documentClosed()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void ghostwriter::DocumentManager::sessionHistoryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
