/********************************************************************************
** Form generated from reading UI file 'preferencesdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFERENCESDIALOG_H
#define UI_PREFERENCESDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_PreferencesDialog
{
public:
    QVBoxLayout *verticalLayout_7;
    QTabWidget *tabWidget;
    QWidget *General;
    QVBoxLayout *verticalLayout_9;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_3;
    QCheckBox *clockCheckBox;
    QCheckBox *menuBarCheckBox;
    QCheckBox *unbreakableSpaceCheckBox;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QComboBox *cornersComboBox;
    QSpacerItem *verticalSpacer_3;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_2;
    QCheckBox *autoSaveCheckBox;
    QCheckBox *backupCheckBox;
    QPushButton *openDraftDirButton;
    QLabel *currentBackupFolderText;
    QPushButton *selectBackupFolderButton;
    QSpacerItem *verticalSpacer_2;
    QGroupBox *groupBox_3;
    QVBoxLayout *verticalLayout;
    QCheckBox *rememberHistoryCheckBox;
    QCheckBox *restoreSessionCheckBox;
    QSpacerItem *verticalSpacer_7;
    QGroupBox *groupBox_7;
    QVBoxLayout *verticalLayout1;
    QCheckBox *folderViewShowAllFilesCheckBox;
    QSpacerItem *verticalSpacer;
    QWidget *Editor;
    QVBoxLayout *verticalLayout_8;
    QGroupBox *groupBox_4;
    QVBoxLayout *verticalLayout_6;
    QCheckBox *spacesCheckBox;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_6;
    QSpinBox *tabWidthInput;
    QSpacerItem *verticalSpacer_6;
    QGroupBox *groupBox_5;
    QVBoxLayout *verticalLayout_5;
    QFormLayout *formLayout;
    QLabel *label_2;
    QComboBox *focusModeCombo;
    QLabel *label_3;
    QComboBox *editorWidthCombo;
    QLabel *label_4;
    QComboBox *blockquoteStyleCombo;
    QLabel *label_5;
    QComboBox *underlineCombo;
    QCheckBox *largeHeadingsCheckBox;
    QSpacerItem *verticalSpacer_5;
    QGroupBox *groupBox_6;
    QVBoxLayout *verticalLayout_4;
    QCheckBox *cycleBulletPointsCheckBox;
    QCheckBox *autoMatchCheckBox;
    QPushButton *matchedCharsButton;
    QSpacerItem *verticalSpacer_4;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *PreferencesDialog)
    {
        if (PreferencesDialog->objectName().isEmpty())
            PreferencesDialog->setObjectName("PreferencesDialog");
        PreferencesDialog->resize(548, 551);
        verticalLayout_7 = new QVBoxLayout(PreferencesDialog);
        verticalLayout_7->setObjectName("verticalLayout_7");
        tabWidget = new QTabWidget(PreferencesDialog);
        tabWidget->setObjectName("tabWidget");
        General = new QWidget();
        General->setObjectName("General");
        verticalLayout_9 = new QVBoxLayout(General);
        verticalLayout_9->setObjectName("verticalLayout_9");
        groupBox = new QGroupBox(General);
        groupBox->setObjectName("groupBox");
        verticalLayout_3 = new QVBoxLayout(groupBox);
        verticalLayout_3->setObjectName("verticalLayout_3");
        clockCheckBox = new QCheckBox(groupBox);
        clockCheckBox->setObjectName("clockCheckBox");

        verticalLayout_3->addWidget(clockCheckBox);

        menuBarCheckBox = new QCheckBox(groupBox);
        menuBarCheckBox->setObjectName("menuBarCheckBox");

        verticalLayout_3->addWidget(menuBarCheckBox);

        unbreakableSpaceCheckBox = new QCheckBox(groupBox);
        unbreakableSpaceCheckBox->setObjectName("unbreakableSpaceCheckBox");

        verticalLayout_3->addWidget(unbreakableSpaceCheckBox);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(groupBox);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        cornersComboBox = new QComboBox(groupBox);
        cornersComboBox->setObjectName("cornersComboBox");

        horizontalLayout->addWidget(cornersComboBox);

        horizontalLayout->setStretch(1, 1);

        verticalLayout_3->addLayout(horizontalLayout);

        verticalSpacer_3 = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer_3);


        verticalLayout_9->addWidget(groupBox);

        groupBox_2 = new QGroupBox(General);
        groupBox_2->setObjectName("groupBox_2");
        verticalLayout_2 = new QVBoxLayout(groupBox_2);
        verticalLayout_2->setObjectName("verticalLayout_2");
        autoSaveCheckBox = new QCheckBox(groupBox_2);
        autoSaveCheckBox->setObjectName("autoSaveCheckBox");

        verticalLayout_2->addWidget(autoSaveCheckBox);

        backupCheckBox = new QCheckBox(groupBox_2);
        backupCheckBox->setObjectName("backupCheckBox");

        verticalLayout_2->addWidget(backupCheckBox);

        openDraftDirButton = new QPushButton(groupBox_2);
        openDraftDirButton->setObjectName("openDraftDirButton");

        verticalLayout_2->addWidget(openDraftDirButton);

        currentBackupFolderText = new QLabel(groupBox_2);
        currentBackupFolderText->setObjectName("currentBackupFolderText");

        verticalLayout_2->addWidget(currentBackupFolderText);

        selectBackupFolderButton = new QPushButton(groupBox_2);
        selectBackupFolderButton->setObjectName("selectBackupFolderButton");

        verticalLayout_2->addWidget(selectBackupFolderButton);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_2);


        verticalLayout_9->addWidget(groupBox_2);

        groupBox_3 = new QGroupBox(General);
        groupBox_3->setObjectName("groupBox_3");
        verticalLayout = new QVBoxLayout(groupBox_3);
        verticalLayout->setObjectName("verticalLayout");
        rememberHistoryCheckBox = new QCheckBox(groupBox_3);
        rememberHistoryCheckBox->setObjectName("rememberHistoryCheckBox");

        verticalLayout->addWidget(rememberHistoryCheckBox);

        restoreSessionCheckBox = new QCheckBox(groupBox_3);
        restoreSessionCheckBox->setObjectName("restoreSessionCheckBox");

        verticalLayout->addWidget(restoreSessionCheckBox);

        verticalSpacer_7 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_7);


        verticalLayout_9->addWidget(groupBox_3);

        groupBox_7 = new QGroupBox(General);
        groupBox_7->setObjectName("groupBox_7");
        verticalLayout1 = new QVBoxLayout(groupBox_7);
        verticalLayout1->setObjectName("verticalLayout1");
        folderViewShowAllFilesCheckBox = new QCheckBox(groupBox_7);
        folderViewShowAllFilesCheckBox->setObjectName("folderViewShowAllFilesCheckBox");

        verticalLayout1->addWidget(folderViewShowAllFilesCheckBox);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout1->addItem(verticalSpacer);


        verticalLayout_9->addWidget(groupBox_7);

        tabWidget->addTab(General, QString());
        Editor = new QWidget();
        Editor->setObjectName("Editor");
        verticalLayout_8 = new QVBoxLayout(Editor);
        verticalLayout_8->setObjectName("verticalLayout_8");
        groupBox_4 = new QGroupBox(Editor);
        groupBox_4->setObjectName("groupBox_4");
        verticalLayout_6 = new QVBoxLayout(groupBox_4);
        verticalLayout_6->setObjectName("verticalLayout_6");
        spacesCheckBox = new QCheckBox(groupBox_4);
        spacesCheckBox->setObjectName("spacesCheckBox");

        verticalLayout_6->addWidget(spacesCheckBox);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label_6 = new QLabel(groupBox_4);
        label_6->setObjectName("label_6");

        horizontalLayout_2->addWidget(label_6);

        tabWidthInput = new QSpinBox(groupBox_4);
        tabWidthInput->setObjectName("tabWidthInput");
        tabWidthInput->setMinimum(1);
        tabWidthInput->setMaximum(8);

        horizontalLayout_2->addWidget(tabWidthInput);

        horizontalLayout_2->setStretch(1, 1);

        verticalLayout_6->addLayout(horizontalLayout_2);

        verticalSpacer_6 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_6->addItem(verticalSpacer_6);


        verticalLayout_8->addWidget(groupBox_4);

        groupBox_5 = new QGroupBox(Editor);
        groupBox_5->setObjectName("groupBox_5");
        verticalLayout_5 = new QVBoxLayout(groupBox_5);
        verticalLayout_5->setObjectName("verticalLayout_5");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        label_2 = new QLabel(groupBox_5);
        label_2->setObjectName("label_2");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_2);

        focusModeCombo = new QComboBox(groupBox_5);
        focusModeCombo->setObjectName("focusModeCombo");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, focusModeCombo);

        label_3 = new QLabel(groupBox_5);
        label_3->setObjectName("label_3");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_3);

        editorWidthCombo = new QComboBox(groupBox_5);
        editorWidthCombo->setObjectName("editorWidthCombo");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, editorWidthCombo);

        label_4 = new QLabel(groupBox_5);
        label_4->setObjectName("label_4");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_4);

        blockquoteStyleCombo = new QComboBox(groupBox_5);
        blockquoteStyleCombo->setObjectName("blockquoteStyleCombo");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, blockquoteStyleCombo);

        label_5 = new QLabel(groupBox_5);
        label_5->setObjectName("label_5");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_5);

        underlineCombo = new QComboBox(groupBox_5);
        underlineCombo->setObjectName("underlineCombo");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, underlineCombo);


        verticalLayout_5->addLayout(formLayout);

        largeHeadingsCheckBox = new QCheckBox(groupBox_5);
        largeHeadingsCheckBox->setObjectName("largeHeadingsCheckBox");

        verticalLayout_5->addWidget(largeHeadingsCheckBox);

        verticalSpacer_5 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_5->addItem(verticalSpacer_5);


        verticalLayout_8->addWidget(groupBox_5);

        groupBox_6 = new QGroupBox(Editor);
        groupBox_6->setObjectName("groupBox_6");
        verticalLayout_4 = new QVBoxLayout(groupBox_6);
        verticalLayout_4->setObjectName("verticalLayout_4");
        cycleBulletPointsCheckBox = new QCheckBox(groupBox_6);
        cycleBulletPointsCheckBox->setObjectName("cycleBulletPointsCheckBox");

        verticalLayout_4->addWidget(cycleBulletPointsCheckBox);

        autoMatchCheckBox = new QCheckBox(groupBox_6);
        autoMatchCheckBox->setObjectName("autoMatchCheckBox");

        verticalLayout_4->addWidget(autoMatchCheckBox);

        matchedCharsButton = new QPushButton(groupBox_6);
        matchedCharsButton->setObjectName("matchedCharsButton");

        verticalLayout_4->addWidget(matchedCharsButton);

        verticalSpacer_4 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_4->addItem(verticalSpacer_4);


        verticalLayout_8->addWidget(groupBox_6);

        tabWidget->addTab(Editor, QString());

        verticalLayout_7->addWidget(tabWidget);

        buttonBox = new QDialogButtonBox(PreferencesDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Close);

        verticalLayout_7->addWidget(buttonBox);

#if QT_CONFIG(shortcut)
        label->setBuddy(cornersComboBox);
        label_6->setBuddy(tabWidthInput);
        label_2->setBuddy(focusModeCombo);
        label_3->setBuddy(editorWidthCombo);
        label_4->setBuddy(blockquoteStyleCombo);
        label_5->setBuddy(underlineCombo);
#endif // QT_CONFIG(shortcut)

        retranslateUi(PreferencesDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, PreferencesDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, PreferencesDialog, qOverload<>(&QDialog::reject));

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(PreferencesDialog);
    } // setupUi

    void retranslateUi(QDialog *PreferencesDialog)
    {
        PreferencesDialog->setWindowTitle(QCoreApplication::translate("PreferencesDialog", "Preferences", nullptr));
        groupBox->setTitle(QCoreApplication::translate("PreferencesDialog", "Display", nullptr));
        clockCheckBox->setText(QCoreApplication::translate("PreferencesDialog", "&Show current time in full screen mode", nullptr));
        menuBarCheckBox->setText(QCoreApplication::translate("PreferencesDialog", "&Hide menu bar in full screen mode", nullptr));
        unbreakableSpaceCheckBox->setText(QCoreApplication::translate("PreferencesDialog", "Show &Unbreakable Space", nullptr));
        label->setText(QCoreApplication::translate("PreferencesDialog", "Interface style", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("PreferencesDialog", "File Saving", nullptr));
        autoSaveCheckBox->setText(QCoreApplication::translate("PreferencesDialog", "&Auto save", nullptr));
        backupCheckBox->setText(QCoreApplication::translate("PreferencesDialog", "&Backup file on save", nullptr));
        openDraftDirButton->setText(QCoreApplication::translate("PreferencesDialog", "&View untitled drafts\342\200\246", nullptr));
        currentBackupFolderText->setText(QCoreApplication::translate("PreferencesDialog", "&", nullptr));
        selectBackupFolderButton->setText(QCoreApplication::translate("PreferencesDialog", "&Select Backup Folder Location\342\200\246", nullptr));
        groupBox_3->setTitle(QCoreApplication::translate("PreferencesDialog", "Session", nullptr));
        rememberHistoryCheckBox->setText(QCoreApplication::translate("PreferencesDialog", "&Remember recent files", nullptr));
        restoreSessionCheckBox->setText(QCoreApplication::translate("PreferencesDialog", "&Open last file on startup", nullptr));
        groupBox_7->setTitle(QCoreApplication::translate("PreferencesDialog", "Sidebar", nullptr));
        folderViewShowAllFilesCheckBox->setText(QCoreApplication::translate("PreferencesDialog", "&Show all files in folder view", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(General), QCoreApplication::translate("PreferencesDialog", "General", nullptr));
        groupBox_4->setTitle(QCoreApplication::translate("PreferencesDialog", "Tabulation", nullptr));
        spacesCheckBox->setText(QCoreApplication::translate("PreferencesDialog", "&Insert spaces for tabs", nullptr));
        label_6->setText(QCoreApplication::translate("PreferencesDialog", "Tabulation width", nullptr));
        groupBox_5->setTitle(QCoreApplication::translate("PreferencesDialog", "Styling", nullptr));
        label_2->setText(QCoreApplication::translate("PreferencesDialog", "Focus mode", nullptr));
        label_3->setText(QCoreApplication::translate("PreferencesDialog", "Editor width", nullptr));
        label_4->setText(QCoreApplication::translate("PreferencesDialog", "Blockquote style", nullptr));
        label_5->setText(QCoreApplication::translate("PreferencesDialog", "Emphasis style", nullptr));
        largeHeadingsCheckBox->setText(QCoreApplication::translate("PreferencesDialog", "&Use large headings", nullptr));
        groupBox_6->setTitle(QCoreApplication::translate("PreferencesDialog", "Typing", nullptr));
        cycleBulletPointsCheckBox->setText(QCoreApplication::translate("PreferencesDialog", "C&ycle bullet point markers", nullptr));
        autoMatchCheckBox->setText(QCoreApplication::translate("PreferencesDialog", "&Automatically match characters", nullptr));
        matchedCharsButton->setText(QCoreApplication::translate("PreferencesDialog", "Customize &matched characters\342\200\246", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(Editor), QCoreApplication::translate("PreferencesDialog", "Editor", nullptr));
    } // retranslateUi

};

namespace Ui {
    class PreferencesDialog: public Ui_PreferencesDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PREFERENCESDIALOG_H
