/****************************************************************************
** Meta object code from reading C++ file 'documentstatistics.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ghostwriter-26.07.80/src/statistics/documentstatistics.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'documentstatistics.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11ghostwriter18DocumentStatisticsE_t {};
} // unnamed namespace

template <> constexpr inline auto ghostwriter::DocumentStatistics::qt_create_metaobjectdata<qt_meta_tag_ZN11ghostwriter18DocumentStatisticsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ghostwriter::DocumentStatistics",
        "wordCountChanged",
        "",
        "value",
        "totalWordCountChanged",
        "characterCountChanged",
        "paragraphCountChanged",
        "sentenceCountChanged",
        "pageCountChanged",
        "complexWordsChanged",
        "percentage",
        "readingTimeChanged",
        "minutes",
        "lixReadingEaseChanged",
        "readabilityIndexChanged",
        "onTextSelected",
        "selectedText",
        "selectionStart",
        "selectionEnd",
        "onTextDeselected",
        "onTextChanged",
        "position",
        "charsRemoved",
        "charsAdded"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'wordCountChanged'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'totalWordCountChanged'
        QtMocHelpers::SignalData<void(int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'characterCountChanged'
        QtMocHelpers::SignalData<void(int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'paragraphCountChanged'
        QtMocHelpers::SignalData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'sentenceCountChanged'
        QtMocHelpers::SignalData<void(int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'pageCountChanged'
        QtMocHelpers::SignalData<void(int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'complexWordsChanged'
        QtMocHelpers::SignalData<void(int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Signal 'readingTimeChanged'
        QtMocHelpers::SignalData<void(int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Signal 'lixReadingEaseChanged'
        QtMocHelpers::SignalData<void(int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'readabilityIndexChanged'
        QtMocHelpers::SignalData<void(int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'onTextSelected'
        QtMocHelpers::SlotData<void(const QString &, int, int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 }, { QMetaType::Int, 17 }, { QMetaType::Int, 18 },
        }}),
        // Slot 'onTextDeselected'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onTextChanged'
        QtMocHelpers::SlotData<void(int, int, int)>(20, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 21 }, { QMetaType::Int, 22 }, { QMetaType::Int, 23 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DocumentStatistics, qt_meta_tag_ZN11ghostwriter18DocumentStatisticsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ghostwriter::DocumentStatistics::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ghostwriter18DocumentStatisticsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ghostwriter18DocumentStatisticsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11ghostwriter18DocumentStatisticsE_t>.metaTypes,
    nullptr
} };

void ghostwriter::DocumentStatistics::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DocumentStatistics *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->wordCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->totalWordCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->characterCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->paragraphCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->sentenceCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->pageCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->complexWordsChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->readingTimeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->lixReadingEaseChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->readabilityIndexChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->onTextSelected((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 11: _t->onTextDeselected(); break;
        case 12: _t->onTextChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DocumentStatistics::*)(int )>(_a, &DocumentStatistics::wordCountChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentStatistics::*)(int )>(_a, &DocumentStatistics::totalWordCountChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentStatistics::*)(int )>(_a, &DocumentStatistics::characterCountChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentStatistics::*)(int )>(_a, &DocumentStatistics::paragraphCountChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentStatistics::*)(int )>(_a, &DocumentStatistics::sentenceCountChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentStatistics::*)(int )>(_a, &DocumentStatistics::pageCountChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentStatistics::*)(int )>(_a, &DocumentStatistics::complexWordsChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentStatistics::*)(int )>(_a, &DocumentStatistics::readingTimeChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentStatistics::*)(int )>(_a, &DocumentStatistics::lixReadingEaseChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentStatistics::*)(int )>(_a, &DocumentStatistics::readabilityIndexChanged, 9))
            return;
    }
}

const QMetaObject *ghostwriter::DocumentStatistics::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ghostwriter::DocumentStatistics::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ghostwriter18DocumentStatisticsE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ghostwriter::DocumentStatistics::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void ghostwriter::DocumentStatistics::wordCountChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ghostwriter::DocumentStatistics::totalWordCountChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ghostwriter::DocumentStatistics::characterCountChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ghostwriter::DocumentStatistics::paragraphCountChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void ghostwriter::DocumentStatistics::sentenceCountChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void ghostwriter::DocumentStatistics::pageCountChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void ghostwriter::DocumentStatistics::complexWordsChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void ghostwriter::DocumentStatistics::readingTimeChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void ghostwriter::DocumentStatistics::lixReadingEaseChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void ghostwriter::DocumentStatistics::readabilityIndexChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}
QT_WARNING_POP
