/****************************************************************************
** Meta object code from reading C++ file 'mainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ghostwriter-26.07.80/src/mainwindow.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11ghostwriter10MainWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto ghostwriter::MainWindow::qt_create_metaobjectdata<qt_meta_tag_ZN11ghostwriter10MainWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ghostwriter::MainWindow",
        "quitApplication",
        "",
        "changeTheme",
        "openPreferencesDialog",
        "toggleHtmlPreview",
        "checked",
        "toggleHemingwayMode",
        "toggleFocusMode",
        "toggleFullScreen",
        "toggleHideMenuBarInFullScreen",
        "toggleFileHistoryEnabled",
        "toggleFolderViewShowAllFilesEnabled",
        "toggleDisplayTimeInFullScreen",
        "changeEditorWidth",
        "EditorWidth",
        "editorWidth",
        "changeInterfaceStyle",
        "InterfaceStyle",
        "style",
        "showQuickReferenceGuide",
        "showWikiPage",
        "changeFocusMode",
        "FocusMode",
        "focusMode",
        "applyTheme",
        "refreshRecentFiles",
        "clearRecentFileHistory",
        "changeDocumentDisplayName",
        "displayName",
        "onOperationStarted",
        "description",
        "onOperationFinished",
        "changeFont",
        "onFontSizeChanged",
        "size",
        "onSetLocale",
        "copyHtml",
        "showPreviewOptions",
        "onAboutToHideMenuBarMenu",
        "onAboutToShowMenuBarMenu",
        "onSidebarVisibilityChanged",
        "visible",
        "toggleSidebarVisible",
        "runSpellCheck"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'quitApplication'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'changeTheme'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openPreferencesDialog'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleHtmlPreview'
        QtMocHelpers::SlotData<void(bool)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'toggleHemingwayMode'
        QtMocHelpers::SlotData<void(bool)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'toggleFocusMode'
        QtMocHelpers::SlotData<void(bool)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'toggleFullScreen'
        QtMocHelpers::SlotData<void(bool)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'toggleHideMenuBarInFullScreen'
        QtMocHelpers::SlotData<void(bool)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'toggleFileHistoryEnabled'
        QtMocHelpers::SlotData<void(bool)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'toggleFolderViewShowAllFilesEnabled'
        QtMocHelpers::SlotData<void(bool)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'toggleDisplayTimeInFullScreen'
        QtMocHelpers::SlotData<void(bool)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'changeEditorWidth'
        QtMocHelpers::SlotData<void(EditorWidth)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'changeInterfaceStyle'
        QtMocHelpers::SlotData<void(InterfaceStyle)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Slot 'showQuickReferenceGuide'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showWikiPage'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'changeFocusMode'
        QtMocHelpers::SlotData<void(FocusMode)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Slot 'applyTheme'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'refreshRecentFiles'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'clearRecentFileHistory'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'changeDocumentDisplayName'
        QtMocHelpers::SlotData<void(const QString &)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 29 },
        }}),
        // Slot 'onOperationStarted'
        QtMocHelpers::SlotData<void(const QString &)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 31 },
        }}),
        // Slot 'onOperationFinished'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'changeFont'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onFontSizeChanged'
        QtMocHelpers::SlotData<void(int)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 35 },
        }}),
        // Slot 'onSetLocale'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'copyHtml'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showPreviewOptions'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onAboutToHideMenuBarMenu'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onAboutToShowMenuBarMenu'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onSidebarVisibilityChanged'
        QtMocHelpers::SlotData<void(bool)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 42 },
        }}),
        // Slot 'toggleSidebarVisible'
        QtMocHelpers::SlotData<void(bool)>(43, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 42 },
        }}),
        // Slot 'runSpellCheck'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MainWindow, qt_meta_tag_ZN11ghostwriter10MainWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ghostwriter::MainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QMainWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ghostwriter10MainWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ghostwriter10MainWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11ghostwriter10MainWindowE_t>.metaTypes,
    nullptr
} };

void ghostwriter::MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MainWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->quitApplication(); break;
        case 1: _t->changeTheme(); break;
        case 2: _t->openPreferencesDialog(); break;
        case 3: _t->toggleHtmlPreview((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->toggleHemingwayMode((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->toggleFocusMode((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->toggleFullScreen((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->toggleHideMenuBarInFullScreen((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->toggleFileHistoryEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->toggleFolderViewShowAllFilesEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->toggleDisplayTimeInFullScreen((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->changeEditorWidth((*reinterpret_cast<std::add_pointer_t<EditorWidth>>(_a[1]))); break;
        case 12: _t->changeInterfaceStyle((*reinterpret_cast<std::add_pointer_t<InterfaceStyle>>(_a[1]))); break;
        case 13: _t->showQuickReferenceGuide(); break;
        case 14: _t->showWikiPage(); break;
        case 15: _t->changeFocusMode((*reinterpret_cast<std::add_pointer_t<FocusMode>>(_a[1]))); break;
        case 16: _t->applyTheme(); break;
        case 17: _t->refreshRecentFiles(); break;
        case 18: _t->clearRecentFileHistory(); break;
        case 19: _t->changeDocumentDisplayName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 20: _t->onOperationStarted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 21: _t->onOperationFinished(); break;
        case 22: _t->changeFont(); break;
        case 23: _t->onFontSizeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 24: _t->onSetLocale(); break;
        case 25: _t->copyHtml(); break;
        case 26: _t->showPreviewOptions(); break;
        case 27: _t->onAboutToHideMenuBarMenu(); break;
        case 28: _t->onAboutToShowMenuBarMenu(); break;
        case 29: _t->onSidebarVisibilityChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 30: _t->toggleSidebarVisible((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 31: _t->runSpellCheck(); break;
        default: ;
        }
    }
}

const QMetaObject *ghostwriter::MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ghostwriter::MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ghostwriter10MainWindowE_t>.strings))
        return static_cast<void*>(this);
    return QMainWindow::qt_metacast(_clname);
}

int ghostwriter::MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 32)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 32)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 32;
    }
    return _id;
}
QT_WARNING_POP
