/****************************************************************************
** Meta object code from reading C++ file 'markdowneditor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ghostwriter-26.07.80/src/editor/markdowneditor.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'markdowneditor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11ghostwriter14MarkdownEditorE_t {};
} // unnamed namespace

template <> constexpr inline auto ghostwriter::MarkdownEditor::qt_create_metaobjectdata<qt_meta_tag_ZN11ghostwriter14MarkdownEditorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ghostwriter::MarkdownEditor",
        "headingFound",
        "",
        "level",
        "text",
        "QTextBlock",
        "block",
        "headingRemoved",
        "position",
        "typingResumed",
        "typingPaused",
        "typingPausedScaled",
        "cursorPositionChanged",
        "textSelected",
        "selectedText",
        "selectionStart",
        "selectionEnd",
        "textDeselected",
        "fontSizeChanged",
        "size",
        "navigateDocument",
        "bold",
        "italic",
        "strikethrough",
        "insertCodeFences",
        "insertComment",
        "createBulletListWithAsteriskMarker",
        "createBulletListWithMinusMarker",
        "createBulletListWithPlusMarker",
        "createNumberedListWithPeriodMarker",
        "createNumberedListWithParenthesisMarker",
        "createTaskList",
        "createBlockquote",
        "removeBlockquote",
        "indentText",
        "unindentText",
        "deselectText",
        "toggleTaskComplete",
        "insertImage",
        "setEnableLargeHeadingSizes",
        "enable",
        "setAutoMatchEnabled",
        "openingCharacter",
        "enabled",
        "setBulletPointCyclingEnabled",
        "setUseUnderlineForEmphasis",
        "setItalicizeBlockquotes",
        "setInsertSpacesForTabs",
        "setTabulationWidth",
        "width",
        "setEditorWidth",
        "EditorWidth",
        "setEditorCorners",
        "InterfaceStyle",
        "corners",
        "increaseFontSize",
        "decreaseFontSize",
        "onContentsChanged",
        "charsRemoved",
        "charsAdded",
        "onSelectionChanged",
        "focusText",
        "checkIfTypingPaused",
        "checkIfTypingPausedScaled",
        "onCursorPositionChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'headingFound'
        QtMocHelpers::SignalData<void(int, const QString &, QTextBlock)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::QString, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'headingRemoved'
        QtMocHelpers::SignalData<void(int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
        // Signal 'typingResumed'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'typingPaused'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'typingPausedScaled'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cursorPositionChanged'
        QtMocHelpers::SignalData<void(int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
        // Signal 'textSelected'
        QtMocHelpers::SignalData<void(const QString &, int, int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 }, { QMetaType::Int, 15 }, { QMetaType::Int, 16 },
        }}),
        // Signal 'textDeselected'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fontSizeChanged'
        QtMocHelpers::SignalData<void(int)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 },
        }}),
        // Slot 'navigateDocument'
        QtMocHelpers::SlotData<void(const int)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
        // Slot 'bold'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'italic'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'strikethrough'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'insertCodeFences'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'insertComment'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'createBulletListWithAsteriskMarker'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'createBulletListWithMinusMarker'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'createBulletListWithPlusMarker'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'createNumberedListWithPeriodMarker'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'createNumberedListWithParenthesisMarker'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'createTaskList'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'createBlockquote'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'removeBlockquote'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'indentText'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'unindentText'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'deselectText'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleTaskComplete'
        QtMocHelpers::SlotData<bool()>(37, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'insertImage'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setEnableLargeHeadingSizes'
        QtMocHelpers::SlotData<void(bool)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 40 },
        }}),
        // Slot 'setAutoMatchEnabled'
        QtMocHelpers::SlotData<void(bool)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 40 },
        }}),
        // Slot 'setAutoMatchEnabled'
        QtMocHelpers::SlotData<void(const QChar, bool)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QChar, 42 }, { QMetaType::Bool, 43 },
        }}),
        // Slot 'setBulletPointCyclingEnabled'
        QtMocHelpers::SlotData<void(bool)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 40 },
        }}),
        // Slot 'setUseUnderlineForEmphasis'
        QtMocHelpers::SlotData<void(bool)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 40 },
        }}),
        // Slot 'setItalicizeBlockquotes'
        QtMocHelpers::SlotData<void(bool)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 40 },
        }}),
        // Slot 'setInsertSpacesForTabs'
        QtMocHelpers::SlotData<void(bool)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 40 },
        }}),
        // Slot 'setTabulationWidth'
        QtMocHelpers::SlotData<void(int)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 49 },
        }}),
        // Slot 'setEditorWidth'
        QtMocHelpers::SlotData<void(EditorWidth)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 51, 49 },
        }}),
        // Slot 'setEditorCorners'
        QtMocHelpers::SlotData<void(InterfaceStyle)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'increaseFontSize'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'decreaseFontSize'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onContentsChanged'
        QtMocHelpers::SlotData<void(int, int, int)>(57, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 8 }, { QMetaType::Int, 58 }, { QMetaType::Int, 59 },
        }}),
        // Slot 'onSelectionChanged'
        QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'focusText'
        QtMocHelpers::SlotData<void()>(61, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'checkIfTypingPaused'
        QtMocHelpers::SlotData<void()>(62, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'checkIfTypingPausedScaled'
        QtMocHelpers::SlotData<void()>(63, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onCursorPositionChanged'
        QtMocHelpers::SlotData<void()>(64, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MarkdownEditor, qt_meta_tag_ZN11ghostwriter14MarkdownEditorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ghostwriter::MarkdownEditor::staticMetaObject = { {
    QMetaObject::SuperData::link<QPlainTextEdit::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ghostwriter14MarkdownEditorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ghostwriter14MarkdownEditorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11ghostwriter14MarkdownEditorE_t>.metaTypes,
    nullptr
} };

void ghostwriter::MarkdownEditor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MarkdownEditor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->headingFound((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QTextBlock>>(_a[3]))); break;
        case 1: _t->headingRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->typingResumed(); break;
        case 3: _t->typingPaused(); break;
        case 4: _t->typingPausedScaled(); break;
        case 5: _t->cursorPositionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->textSelected((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 7: _t->textDeselected(); break;
        case 8: _t->fontSizeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->navigateDocument((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->bold(); break;
        case 11: _t->italic(); break;
        case 12: _t->strikethrough(); break;
        case 13: _t->insertCodeFences(); break;
        case 14: _t->insertComment(); break;
        case 15: _t->createBulletListWithAsteriskMarker(); break;
        case 16: _t->createBulletListWithMinusMarker(); break;
        case 17: _t->createBulletListWithPlusMarker(); break;
        case 18: _t->createNumberedListWithPeriodMarker(); break;
        case 19: _t->createNumberedListWithParenthesisMarker(); break;
        case 20: _t->createTaskList(); break;
        case 21: _t->createBlockquote(); break;
        case 22: _t->removeBlockquote(); break;
        case 23: _t->indentText(); break;
        case 24: _t->unindentText(); break;
        case 25: _t->deselectText(); break;
        case 26: { bool _r = _t->toggleTaskComplete();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 27: _t->insertImage(); break;
        case 28: _t->setEnableLargeHeadingSizes((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 29: _t->setAutoMatchEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 30: _t->setAutoMatchEnabled((*reinterpret_cast<std::add_pointer_t<QChar>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 31: _t->setBulletPointCyclingEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 32: _t->setUseUnderlineForEmphasis((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 33: _t->setItalicizeBlockquotes((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 34: _t->setInsertSpacesForTabs((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 35: _t->setTabulationWidth((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 36: _t->setEditorWidth((*reinterpret_cast<std::add_pointer_t<EditorWidth>>(_a[1]))); break;
        case 37: _t->setEditorCorners((*reinterpret_cast<std::add_pointer_t<InterfaceStyle>>(_a[1]))); break;
        case 38: _t->increaseFontSize(); break;
        case 39: _t->decreaseFontSize(); break;
        case 40: _t->onContentsChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 41: _t->onSelectionChanged(); break;
        case 42: _t->focusText(); break;
        case 43: _t->checkIfTypingPaused(); break;
        case 44: _t->checkIfTypingPausedScaled(); break;
        case 45: _t->onCursorPositionChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MarkdownEditor::*)(int , const QString & , QTextBlock )>(_a, &MarkdownEditor::headingFound, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarkdownEditor::*)(int )>(_a, &MarkdownEditor::headingRemoved, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarkdownEditor::*)()>(_a, &MarkdownEditor::typingResumed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarkdownEditor::*)()>(_a, &MarkdownEditor::typingPaused, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarkdownEditor::*)()>(_a, &MarkdownEditor::typingPausedScaled, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarkdownEditor::*)(int )>(_a, &MarkdownEditor::cursorPositionChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarkdownEditor::*)(const QString & , int , int )>(_a, &MarkdownEditor::textSelected, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarkdownEditor::*)()>(_a, &MarkdownEditor::textDeselected, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarkdownEditor::*)(int )>(_a, &MarkdownEditor::fontSizeChanged, 8))
            return;
    }
}

const QMetaObject *ghostwriter::MarkdownEditor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ghostwriter::MarkdownEditor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ghostwriter14MarkdownEditorE_t>.strings))
        return static_cast<void*>(this);
    return QPlainTextEdit::qt_metacast(_clname);
}

int ghostwriter::MarkdownEditor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QPlainTextEdit::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 46)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 46;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 46)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 46;
    }
    return _id;
}

// SIGNAL 0
void ghostwriter::MarkdownEditor::headingFound(int _t1, const QString & _t2, QTextBlock _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void ghostwriter::MarkdownEditor::headingRemoved(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ghostwriter::MarkdownEditor::typingResumed()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ghostwriter::MarkdownEditor::typingPaused()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ghostwriter::MarkdownEditor::typingPausedScaled()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ghostwriter::MarkdownEditor::cursorPositionChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void ghostwriter::MarkdownEditor::textSelected(const QString & _t1, int _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2, _t3);
}

// SIGNAL 7
void ghostwriter::MarkdownEditor::textDeselected()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void ghostwriter::MarkdownEditor::fontSizeChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}
QT_WARNING_POP
